Constructs an LookBackOptions object with the specified settings.

createLookBackOptions(lookBackDays = 99999L, useObservedTimeOnly = FALSE)

Arguments

lookBackDays

An integer number of days for the lookback period.

useObservedTimeOnly

Logical: TRUE restricts the lookback period to only using observed periods.

Value

A LookBackOptions R6 object.