Constructs an IncidenceAnalysis object with the specified settings.

createRassenIncidenceAnalysis(
  analysisId,
  targetCohort,
  periodOfInterest,
  minimumObservationLength = 0L,
  useOnlyFirstObservationPeriod = FALSE,
  multiplier = 100000L,
  strata = NULL,
  demographicConstraints = createDemographicConstraints(),
  populationCohort = NULL
)

Arguments

analysisId

Unique integer analysisId to identify the analysis (required).

targetCohort

A TargetCohort object specifying the cohort of interest (required).

periodOfInterest

A PeriodOfInterest object (required).

useOnlyFirstObservationPeriod

Logical: TRUE to restrict analysis to the first observation period (optional).

multiplier

Integer specifying prevalence multiplier (optional).

strata

Character string. Must be one, or some of: "age", "gender", "race" (optional).

demographicConstraints

a DemoConstraint object specifying the constraints of the population.

populationCohort

A CohortPopulation object specifying the population of interest on which to compute prevalence.

minimumObservationLength:

Integer specifying minimum observation length (optional).

Value

A IncidenceAnalysis R6 object.