Describes a study cohort used as the numerator (prevalent) or target (incidence) in an analysis.
Uses the era pattern (interval overlap) for all analyses.
Methods
Method new()
Create a new TargetCohort object
Arguments
id
Integer cohort ID within the database results schema.
name
Character cohort name.
Method id()
Return the cohort ID.
Method name()
Return the cohort name.
Method viewCohortInfo()
Return a formatted info string about this cohort.
Usage
TargetCohort$viewCohortInfo()
Method clone()
The objects of this class are cloneable with this method.
Usage
TargetCohort$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.