CohortPrevalenceAnalysis objectcreateCohortPrevalenceAnalysis.RdConstructs an CohortPrevalenceAnalysis object with the specified settings.
createCohortPrevalenceAnalysis(
analysisId,
prevalentCohort,
periodOfInterest,
lookBackOptions,
numeratorType,
denominatorType,
minimumObservationLength = 0L,
useOnlyFirstObservationPeriod = FALSE,
multiplier = 100000L,
strata = NULL,
demographicConstraints = createDemographicConstraints(),
populationCohort = NULL
)Unique integer analysisId to identify the analysis (required).
A PrevalenceCohort object specifying the cohort of interest (required).
A PeriodOfInterest object (required).
Character string specifying numerator type. Must be one of:
"pn1": Patients who have been observed to have the condition of interest on the first day of the period of interest or within the lookback time
"pn2": patients who have been observed to have the condition of interest at any time in the period of interest or within the lookback time
A DenominatorType object (required).
Logical: TRUE to restrict analysis to the first observation period (optional).
Integer specifying prevalence multiplier (optional).
Character string. Must be one, or some of: "age", "gender", "race" (optional).
a DemoConstraint object specifying the constraints of the population.
A CohortPopulation object specifying the population of interest on which to compute prevalence.
A LookBackOption object (required).
Integer specifying minimum observation length (optional).
A CohortPrevalenceAnalysis R6 object.