IncidenceAnalysis object for Rassen IncidencecreateRassenIncidenceAnalysis.RdConstructs an IncidenceAnalysis object with the specified settings.
createRassenIncidenceAnalysis(
analysisId,
targetCohort,
periodOfInterest,
minimumObservationLength = 0L,
useOnlyFirstObservationPeriod = FALSE,
multiplier = 100000L,
strata = NULL,
demographicConstraints = createDemographicConstraints(),
populationCohort = NULL
)Unique integer analysisId to identify the analysis (required).
A TargetCohort object specifying the cohort of interest (required).
A PeriodOfInterest object (required).
Logical: TRUE to restrict analysis to the first observation period (optional).
Integer specifying prevalence multiplier (optional).
Character string. Must be one, or some of: "age", "gender", "race" (optional).
a DemoConstraint object specifying the constraints of the population.
A CohortPopulation object specifying the population of interest on which to compute prevalence.
Integer specifying minimum observation length (optional).
A IncidenceAnalysis R6 object.